pub struct ContractPart {
pub meta: Bo4eMeta,
pub contract_part_start: Option<String>,
pub contract_part_end: Option<String>,
pub location_id: Option<String>,
pub fixed_quantity_value: Option<f64>,
pub minimum_quantity_value: Option<f64>,
pub maximum_quantity_value: Option<f64>,
}Expand description
Part of a contract linking a service to a location.
Used to represent a contractual service in relation to a location (market or metering location). Contracts for multiple locations are modeled with multiple contract parts.
German: Vertragsteil
Example
use bo4e_core::com::ContractPart;
let part = ContractPart {
location_id: Some("DE0001234567890123456789012345678".to_string()),
contract_part_start: Some("2024-01-01T00:00:00+01:00".to_string()),
contract_part_end: Some("2024-12-31T23:59:59+01:00".to_string()),
..Default::default()
};Fields
meta: Bo4eMetaBO4E metadata
contract_part_start: Option<String>Start of the contract part validity (inclusive) (Vertragsteilbeginn)
contract_part_end: Option<String>End of the contract part validity (exclusive) (Vertragsteilende)
location_id: Option<String>Identifier for the market or metering location belonging to this contract part (Lokation)
fixed_quantity_value: Option<f64>Contractually fixed consumption quantity (Vertraglich fixierte Menge)
minimum_quantity_value: Option<f64>Minimum consumption quantity (inclusive) (Minimale Abnahmemenge)
maximum_quantity_value: Option<f64>Maximum consumption quantity (exclusive) (Maximale Abnahmemenge)