pub struct OfferPart {
pub meta: Bo4eMeta,
pub request_sub_reference: Option<String>,
pub position_count: Option<i32>,
pub total_quantity_value: Option<f64>,
pub total_cost_value: Option<f64>,
pub delivery_period_start: Option<String>,
pub delivery_period_end: Option<String>,
}Expand description
Part of an offer variant.
Aggregates offer positions. Offer parts are typically created for a market location or delivery address. Contains the quantities and total costs of all offer positions. A variant consists of at least one offer part.
German: Angebotsteil
Example
use bo4e_core::com::OfferPart;
let part = OfferPart {
request_sub_reference: Some("Lot 1".to_string()),
..Default::default()
};Fields
meta: Bo4eMetaBO4E metadata
request_sub_reference: Option<String>Sub-reference identifying a sub-chapter of a request, e.g., tender lot (AnfrageSubreferenz)
position_count: Option<i32>Number of positions in this offer part
total_quantity_value: Option<f64>Total quantity value for this offer part (simplified - Gesamtmengeangebotsteil)
total_cost_value: Option<f64>Total cost value for this offer part (simplified - Gesamtkostenangebotsteil)
delivery_period_start: Option<String>Delivery period start (simplified - Lieferzeitraum)
delivery_period_end: Option<String>Delivery period end (simplified - Lieferzeitraum)