#[non_exhaustive]pub enum BusinessPartnerRole {
Supplier,
ServiceProvider,
Customer,
InterestedParty,
MarketPartner,
NetworkOperator,
}Expand description
Role of a business partner in the energy market.
These roles define the capacity in which a business partner operates.
German: Geschaeftspartnerrolle
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Supplier
Supplier (Lieferant)
ServiceProvider
Service provider (Dienstleister)
Customer
Customer (Kunde)
InterestedParty
Interested party (Interessent)
MarketPartner
Market partner (Marktpartner)
NetworkOperator
Network operator (Netzbetreiber)
Implementations
Sourceimpl BusinessPartnerRole
impl BusinessPartnerRole
Sourcepub fn german_name(&self) -> &'static str
pub fn german_name(&self) -> &'static str
Returns the German name.