CalculationMethod

Enum CalculationMethod 

#[non_exhaustive]
pub enum CalculationMethod {
Show 16 variants Steps, Zones, PreZoneBasePrice, Sigmoid, ReactivePowerAbove50Percent, ReactivePowerAbove40Percent, ReactivePowerWithFreeAllowance, WorkingAndBasePriceZoned, CapacityChargeInstalledCapacity, WorkingPriceTransportOrDistribution, WorkingPriceTransportOrDistributionLocalSigmoid, CapacityChargeAnnualConsumption, CapacityPriceTransportOrDistribution, CapacityPriceTransportOrDistributionLocalSigmoid, Functions, ConsumptionAboveSLPThresholdFunctionBasedLGK,
}
Calculation method for price sheets.

List of different calculation methods for a price sheet.

German: Kalkulationsmethode

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Steps

Step model - total quantity is assigned to one step and the price applies to entire quantity



Zones

Zone model - total quantity is distributed across zones with respective prices



PreZoneBasePrice

Pre-zone base price (Vorzonengrundpreis)



Sigmoid

Sigmoid function (Sigmoidfunktion)



ReactivePowerAbove50Percent

Reactive power above 50% of active power



ReactivePowerAbove40Percent

Reactive power above 40% of active power



ReactivePowerWithFreeAllowance

Reactive power with free allowance (defined by cos phi or percentage)



WorkingAndBasePriceZoned

Working and base price zoned



CapacityChargeInstalledCapacity

Capacity charge based on installed capacity



WorkingPriceTransportOrDistribution

Working price based on transport or distribution network



WorkingPriceTransportOrDistributionLocalSigmoid

Working price based on transport/distribution network, local network via sigmoid



CapacityChargeAnnualConsumption

Capacity charge based on annual consumption



CapacityPriceTransportOrDistribution

Capacity price based on transport or distribution network



CapacityPriceTransportOrDistributionLocalSigmoid

Capacity price based on transport/distribution network, local network via sigmoid



Functions

Function-based capacity determination for consumption above SLP threshold



ConsumptionAboveSLPThresholdFunctionBasedLGK

Above SLP threshold, function-based calculation as LGK

Implementations

Source

impl CalculationMethod

pub fn german_name(&self) -> &'static str

Returns the German name.