#[non_exhaustive]pub enum CostClass {
ExternalCosts,
Procurement,
InternalCosts,
Margins,
EnergySupplyCosts,
}Expand description
Cost class categorization.
Cost classes form the top level of different costs. Typically, total costs of a cost class are calculated in an application.
German: Kostenklasse
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ExternalCosts
External costs (Fremdkosten)
Procurement
Procurement costs (Beschaffung)
InternalCosts
Internal costs (Selbstkosten)
Margins
Margins (Margen)
EnergySupplyCosts
Energy supply costs (Energieversorgungskosten)
Implementations