TariffCalculationMethod

Enum TariffCalculationMethod 

#[non_exhaustive]
pub enum TariffCalculationMethod { None, Tiers, Zones, BestBillingTier, PackagePrice, }
Tariff calculation method.

List of different calculation methods for a price sheet in tariff context.

German: Tarifkalkulationsmethode

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No calculation, just multiply quantity by price



Tiers

Tier model - total quantity assigned to one tier, price applies to entire quantity



Zones

Zone model - total quantity distributed across zones with respective prices



BestBillingTier

Best billing within tiers



PackagePrice

Package price (price for a quantity package)

Implementations

Source

impl TariffCalculationMethod

pub fn german_name(&self) -> &'static str

Returns the German name.