UnitPrefix

Enum UnitPrefix 

#[non_exhaustive]
pub enum UnitPrefix {
Show 17 variants Exa, Peta, Tera, Giga, Mega, Kilo, Hecto, Deca, None, Deci, Centi, Milli, Micro, Nano, Pico, Femto, Atto,
}
SI unit prefix.

Metric prefixes used with units of measurement.

German: Mengeneinheitenpraefix

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Exa

Exa (10^18)



Peta

Peta (10^15)



Tera

Tera (10^12)



Giga

Giga (10^9)



Mega

Mega (10^6)



Kilo

Kilo (10^3)



Hecto

Hecto (10^2)



Deca

Deca (10^1)



None

No prefix (10^0)



Deci

Deci (10^-1)



Centi

Centi (10^-2)



Milli

Milli (10^-3)



Micro

Micro (10^-6)



Nano

Nano (10^-9)



Pico

Pico (10^-12)



Femto

Femto (10^-15)



Atto

Atto (10^-18)

Implementations

Source

impl UnitPrefix

pub fn german_name(&self) -> &'static str

Returns the German name.

pub fn exponent(&self) -> i32

Returns the power of 10 for this prefix.