pub trait Bo4eObject {
// Required methods
fn type_name_german() -> &'static str;
fn type_name_english() -> &'static str;
fn meta(&self) -> &Bo4eMeta;
fn meta_mut(&mut self) -> &mut Bo4eMeta;
}Expand description
Trait implemented by all BO4E types.
This trait provides a common interface for accessing type metadata and enables generic programming over BO4E types.
Required Methods
Sourcefn type_name_german() -> &'static str
fn type_name_german() -> &'static str
Returns the German type name as used in the _typ field.
Example: "Zaehler" for Meter, "Marktlokation" for MarketLocation
Sourcefn type_name_english() -> &'static str
fn type_name_english() -> &'static str
Returns the English type name.
Example: "Meter", "MarketLocation"
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.